@@ -193,7 +193,9 @@ class Titration:
                 #        tau_ref_name = sites[chain][site].getRefTautomerName()
                 #        site_numb_n_ref[chain][site] = tau_ref_name
 
-                cleanPDB(self.molecules, chains_res, inputpqr, outputpqr)
+                cleanPDB(
+                    self.molecules, chains_res, inputpqr, outputpqr, automatic_sites
+                )
                 create_tit_sites(chains_res, TMPpdb=True)
                 f_in = "TMP.pdb"
         else:
@@ -885,9 +887,9 @@ class Titration:
     @staticmethod
     def getParametersDict():
         return (
-            Config.pypka_params.__dict__,
-            Config.delphi_params.__dict__,
-            Config.mc_params.__dict__,
+            Config.pypka_params.get_clean_params(),
+            Config.delphi_params.get_clean_params(),
+            Config.mc_params.get_clean_params(),
         )
 
     def getSiteInteractions(self):
@@ -930,4 +932,4 @@ def CLI():
 
 
 if __name__ == "__main__":
-    CLI()
\ No newline at end of file
+    CLI()
